@@ -66,4 +66,4 @@ class CreateBranch:
 
         self._git.checkout(parent_branch_name)
 
-        self._git.checkout(branch_name)
+        self._git.checkout(branch_name, new=True)
