@@ -61,7 +61,7 @@ class MergePR:
         else:
             logger.info("Pull request mergiata su master!")
 
-        self._git.fetch(self._project)
+        self._git.fetch()
         if self._git.remote_branch_exists(branch_name):
             self._git.delete_remote_branch(branch_name)
 
