@@ -1,6 +1,4 @@
 # -*- encoding: utf-8 -*-
-import sys
-
 from PyInquirer import prompt
 
 
@@ -54,8 +52,3 @@ def ask_choices(question_text, choices, default_text=""):
 
     answer = prompt(questions)
     return answer["value"]
-
-
-def project_confirmation(project):
-    if not ask_confirm(f"Vuoi continuare sul progetto {project}?"):
-        sys.exit(-1)
