@@ -14,19 +14,19 @@ class YoutrackHandler:
         self._client = Connection(url=config.youtrack["url"], token=tokens.youtrack)
 
     def get_projects(self):
-        return self._client.get_projects()
+        return self._client.getProjects()
 
     def get_users(self):
-        return self._client.get_users()
+        return self._client.getUsers()
 
     def get_issue(self, issue_id):
-        return self._client.get_issue(issue_id)
+        return self._client.getIssue(issue_id)
 
     def get_comments(self, issue_id):
-        return self._client.get_comments(issue_id)
+        return self._client.getComments(issue_id)
 
     def update_deployed_field(self, issue_id):
-        return self._client.execute_command(issue_id, "Deployed Today")
+        return self._client.executeCommand(issue_id, "Deployed Today")
 
     def validate_issue(self, issue_id):
         try:
@@ -37,23 +37,20 @@ class YoutrackHandler:
         return False
 
     def comment(self, issue_id, comment):
-        self._client.execute_command(issue_id, "comment", comment=comment)
+        self._client.executeCommand(issue_id, "comment", comment=comment)
 
     def update_state(self, issue_id, status):
-        self._client.execute_command(issue_id, f"State {status}")
+        self._client.executeCommand(issue_id, f"State {status}")
 
     def add_tag(self, issue_id, label):
-        self._client.execute_command(issue_id, f"tag {label}")
+        self._client.executeCommand(issue_id, f"tag {label}")
 
     def assign_to(self, issue_id, user):
-        self._client.execute_command(issue_id, f"Assignee {user}")
+        self._client.executeCommand(issue_id, f"Assignee {user}")
 
     def get_link(self, issue_id):
         return f"{URL}{issue_id}"
 
-    def update_issue(self, issue_id, summary, description):
-        return self._client.update_issue(issue_id, summary, description)
-
     def get_issue_ids(self, commits):
         issue_ids = []
         for c in commits:
